==> plotutils-2.5.tar.gz: plotutils-2.5/lib/xmalloc.c <==
/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.

   The GNU plotutils package is free software.  You may redistribute it
   and/or modify it under the terms of the GNU General Public License as
   published by the Free Software foundation; either version 2, or (at your
   option) any later version.

   The GNU plotutils package is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with the GNU plotutils package; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
   Boston, MA 02110-1301, USA. */

#include "libcommon.h"

void * 
xmalloc (size_t length)
{
  void * p;
  p = (void *) malloc (length);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}

void * 
xrealloc (void * p, size_t length)
{
  p = (void *) realloc (p, length);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}

void * 
xcalloc (size_t nmemb, size_t size)
{
  void * p;
  p = (void *) calloc (nmemb, size);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}

==> plotutils_2.6.orig.tar.gz: plotutils-2.6/lib/xmalloc.c <==
/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
   1996, 1997, 1998, 1999, 2000, 2005, 2008, Free Software Foundation, Inc.

   The GNU plotutils package is free software.  You may redistribute it
   and/or modify it under the terms of the GNU General Public License as
   published by the Free Software foundation; either version 2, or (at your
   option) any later version.

   The GNU plotutils package is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with the GNU plotutils package; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
   Boston, MA 02110-1301, USA. */

#include "libcommon.h"

void * 
xmalloc (size_t length)
{
  void * p;
  p = (void *) malloc (length);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}

void * 
xrealloc (void * p, size_t length)
{
  p = (void *) realloc (p, length);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}

void * 
xcalloc (size_t nmemb, size_t size)
{
  void * p;
  p = (void *) calloc (nmemb, size);

  if (p == (void *) NULL)
    {
      perror ("out of memory");
      exit (EXIT_FAILURE);
    }
  return p;
}
